@@ -54,7 +54,7 @@ MONGOCTL_PARSER_DEF = {
             "action": "store_true",
             "default": False
         },
-        
+
         {
             "name": "yesToEverything",
             "type" : "optional",
@@ -107,6 +107,10 @@ MONGOCTL_PARSER_DEF = {
             {
             "name" :"clusterCommands",
             "display": "Cluster Commands"
+        },
+            {
+            "name" :"miscCommands",
+            "display": "Miscellaneous"
         }
     ],
 
@@ -727,15 +731,15 @@ MONGOCTL_PARSER_DEF = {
             {
             "prog": "status",
             "group": "serverCommands",
-            "shortDescription" : "retrieve status of server",
-            "description" : "Retrieves the status of a server.",
+            "shortDescription" : "retrieve status of server or a cluster",
+            "description" : "Retrieves the status of a server or a cluster.",
             "function": "mongoctl.mongoctl.status_command",
             "args":[
-                    {   "name": "server",
+                    {   "name": "id",
                         "type" : "positional",
                         "nargs": 1,
-                        "displayName": "SERVER_ID",
-                        "help": "A valid server id"
+                        "displayName": "[SERVER OR CLUSTER ID]",
+                        "help": "A valid server or cluster id"
                 },
                     {   "name": "statusVerbose",
                         "type" : "optional",
@@ -795,9 +799,9 @@ MONGOCTL_PARSER_DEF = {
             "description" : "Opens a mongo shell connection to the specified database. If a\n"
                             "cluster is specified command will connect to the primary server.\n\n"
                             "<db-address> can be one of:\n"
-                            "   (a) a mongodb URI (e.g. mongodb://localhost:27017/mydb)\n"
-                            "   (b) <server-id>/<db>\n"
-                            "   (c) <cluster-id>/<db> (not yet supported)\n",
+                            "   (a) a mongodb URI (e.g. mongodb://localhost:27017[/mydb])\n"
+                            "   (b) <server-id>[/<db>]\n"
+                            "   (c) <cluster-id>[/<db>]\n",
             "function": "mongoctl.mongoctl.connect_command",
             "args": [
                     {
@@ -900,6 +904,243 @@ MONGOCTL_PARSER_DEF = {
 
             ]
         },
+        #### tail-log ####
+            {
+            "prog": "tail-log",
+            "group": "serverCommands",
+            "shortDescription" : "tails a server's log file",
+            "description" : "Tails server's log file. Works only on local host",
+            "function": "mongoctl.mongoctl.tail_log_command",
+            "args": [
+                    {
+                    "name": "server",
+                    "type" : "positional",
+                    "nargs": 1,
+                    "displayName": "SERVER_ID",
+                    "help": "a valid server id"
+                },
+                    {
+                    "name": "assumeLocal",
+                    "type" : "optional",
+                    "cmd_arg": "--assume-local",
+                    "nargs": 0,
+                    "help": "Assumes that the server is running on local"
+                            " host. This will skip local address/dns check",
+                    "default": False
+                }
+            ]
+        },
+
+        #### dump ####
+            {
+            "prog": "dump",
+            "group": "clientCommands",
+            "shortDescription" : "Export MongoDB data to BSON files (using mongodump)",
+            "description" : "Runs a mongodump  to the specified database address or dbpath. If a\n"
+                            "cluster is specified command will run the dump against "
+                            "the primary server.\n\n"
+                            "<db-address> can be one of:\n"
+                            "   (a) a mongodb URI (e.g. mongodb://localhost:27017[/mydb])\n"
+                            "   (b) <server-id>[/<db>]\n"
+                            "   (c) <cluster-id>[/<db>]\n",
+            "function": "mongoctl.mongoctl.dump_command",
+            "args": [
+                    {
+                    "name": "dbAddress",
+                    "displayName": "DB_ADDRESS",
+                    "type" : "optional",
+                    "cmd_arg": [
+                        "--db-address"
+                    ],
+                    "nargs": 1,
+                    "help": "database addresses supported by mongoctl."
+                            " Check docs for more details."
+                },
+                    {
+                    "name": "username",
+                    "type" : "optional",
+                    "help": "username",
+                    "cmd_arg": [
+                        "-u"
+                    ],
+                    "nargs": 1
+                },
+                    {
+                    "name": "password",
+                    "type" : "optional",
+                    "help": "password",
+                    "cmd_arg": [
+                        "-p"
+                    ],
+                    "nargs": "?"
+                },
+
+                    {
+                    "name": "verbose",
+                    "type" : "optional",
+                    "help": 'increase verbosity',
+                    "cmd_arg": [
+                        "-v",
+                        "--verbose"
+                    ],
+                    "nargs": 0
+                },
+
+                    {
+                    "name": "dbpath",
+                    "type" : "optional",
+                    "displayName": "DBPATH",
+                    "help": "directly access mongod database files in the given "
+                            "path, instead of connecting to a mongod  server -"
+                            " needs to lock the data directory, so cannot be used "
+                            "if a mongod is currently accessing the same path ",
+                    "cmd_arg": [
+                        "--dbpath"
+                    ],
+                    "nargs": 1
+                },
+
+                    {
+                    "name": "directoryperdb",
+                    "type" : "optional",
+                    "help": "if dbpath specified, each db is in a separate directory",
+                    "cmd_arg": [
+                        "--directoryperdb"
+                    ],
+                    "nargs": 0
+                },
+
+                    {
+                    "name": "journal",
+                    "type" : "optional",
+                    "help": "enable journaling",
+                    "cmd_arg": [
+                        "--journal"
+                    ],
+                    "nargs": 0
+                },
+
+                    {
+                    "name": "collection",
+                    "type" : "optional",
+                    "displayName": "COLLECTION",
+                    "help": "if dbpath specified, each db is in a separate directory",
+                    "cmd_arg": [
+                        "-c",
+                        "--collection"
+                    ],
+                    "nargs": 1
+                },
+
+                    {
+                    "name": "out",
+                    "type" : "optional",
+                    "displayName": "DIR",
+                    "help": "output directory or '-' for stdout",
+                    "cmd_arg": [
+                        "-o",
+                        "--out"
+                    ],
+                    "nargs": 1
+                },
+
+                    {
+                    "name": "query",
+                    "type" : "optional",
+                    "displayName": "QUERY",
+                    "help": "json query",
+                    "cmd_arg": [
+                        "-q",
+                        "--query"
+                    ],
+                    "nargs": 1
+                },
+
+                    {
+                    "name": "oplog",
+                    "type" : "optional",
+                    "help": " Use oplog for point-in-time snapshotting",
+                    "cmd_arg": [
+                        "--oplog"
+                    ],
+                    "nargs": 0
+                },
+
+                    {
+                    "name": "repair",
+                    "type" : "optional",
+                    "help": " try to recover a crashed database",
+                    "cmd_arg": [
+                        "--repair"
+                    ],
+                    "nargs": 0
+                },
+
+                    {
+                    "name": "forceTableScan",
+                    "type" : "optional",
+                    "help": " force a table scan (do not use $snapshot)",
+                    "cmd_arg": [
+                        "--forceTableScan"
+                    ],
+                    "nargs": 0
+                },
+                    {
+                    "name": "ipv6",
+                    "type" : "optional",
+                    "cmd_arg":  "--ipv6",
+                    "nargs": 0,
+                    "help": "enable IPv6 support (disabled by default)"
+                }
+
+            ]
+        },
+
+        #### resync-secondary ####
+            {
+            "prog": "resync-secondary",
+            "group": "serverCommands",
+            "shortDescription" : "Resyncs a secondary member",
+            "description" : "Resyncs a secondary member",
+            "function": "mongoctl.mongoctl.resync_secondary_command",
+            "args": [
+                    {
+                    "name": "server",
+                    "type" : "positional",
+                    "nargs": 1,
+                    "displayName": "SERVER_ID",
+                    "help": "a valid server id"
+                },
+                    {
+                    "name": "assumeLocal",
+                    "type" : "optional",
+                    "cmd_arg": "--assume-local",
+                    "nargs": 0,
+                    "help": "Assumes that the server is running on local"
+                            " host. This will skip local address/dns check",
+                    "default": False
+                },
+                    {
+                    "name": "username",
+                    "type" : "optional",
+                    "help": "admin username",
+                    "cmd_arg": [
+                        "-u"
+                    ],
+                    "nargs": 1
+                },
+                    {
+                    "name": "password",
+                    "type" : "optional",
+                    "help": "admin password",
+                    "cmd_arg": [
+                        "-p"
+                    ],
+                    "nargs": "?"
+                }
+            ]
+        },
+
         #### configure-cluster ####
             {
             "prog": "configure-cluster",
@@ -1029,7 +1270,36 @@ MONGOCTL_PARSER_DEF = {
             "description" : "list all available MongoDB installations on"
                             " this machine",
             "function": "mongoctl.mongoctl.list_versions_command",
-        }
+        },
+        #### print-uri ####
+            {
+            "prog": "print-uri",
+            "group": "miscCommands",
+            "shortDescription" : "prints connection URI for a"
+                                 " server or cluster",
+            "description" : "Prints MongoDB connection URI of the specified"
+                            " server or clurter",
+            "function": "mongoctl.mongoctl.print_uri_command",
+            "args": [
+                    {
+                    "name": "id",
+                    "type" : "positional",
+                    "nargs": 1,
+                    "displayName": "SERVER or CLUSTER ID",
+                    "help": "Server or cluster id"
+                },
+                    {
+                    "name": "db",
+                    "type" : "optional",
+                    "help": "database name",
+                    "cmd_arg": [
+                        "-d",
+                        "--db"
+                    ],
+                    "nargs": 1
+                }
+            ]
+            }
 
 
         ]
